from typing import Annotated

import typer
from mm_std import print_plain

from mm_btc.cli import cli_utils
from mm_btc.cli.cmd import mnemonic_cmd

app = typer.Typer(no_args_is_help=True, pretty_exceptions_enable=False, add_completion=False)


@app.command(name="mnemonic", help="Generate keys based on a mnemonic")
def mnemonic_command(  # nosec B107:hardcoded_password_default
    mnemonic: Annotated[str, typer.Option("--mnemonic", "-m", help="")] = "",
    passphrase: Annotated[str, typer.Option("--passphrase", "-pass")] = "",
    path: Annotated[str, typer.Option("--path", help="Derivation path. Examples: bip44, bip88, m/44'/0'/0'/0")] = "bip44",
    words: int = typer.Option(12, "--words", "-w", help="Number of mnemonic words"),
    limit: int = typer.Option(10, "--limit", "-l"),
    testnet: bool = typer.Option(False, "--testnet", "-t", help="Testnet network"),
) -> None:
    mnemonic_cmd.run(
        mnemonic_cmd.Args(
            mnemonic=mnemonic,
            passphrase=passphrase,
            words=words,
            limit=limit,
            path=path,
            testnet=testnet,
        )
    )


def version_callback(value: bool) -> None:
    if value:
        print_plain(f"mm-eth version: {cli_utils.get_version()}")
        raise typer.Exit()


@app.callback()
def main(_version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True)) -> None:
    pass


if __name__ == "__main_":
    app()



from mm_btc import blockstream


def test_get_address(binance_address):
    # non-empty address
    res = blockstream.get_address(binance_address)
    assert res.unwrap().chain_stats.tx_count > 800

    # empty address
    res = blockstream.get_address("bc1pa48c294qk7yd7sc8y0wxydc3a2frv5j83e65rvm48v3ej098s5zs8kvh6d")
    assert res.unwrap().chain_stats.tx_count == 0

    # invalid address
    res = blockstream.get_address("bc1pa48c294qk7yd7sc8y0wxydc3a2frv5j83e65rvm48v3ej098s5zs8kvh5d")
    assert res.unwrap_err() == blockstream.ERROR_INVALID_ADDRESS

    # invalid network
    res = blockstream.get_address(binance_address, testnet=True)
    assert res.unwrap_err() == blockstream.ERROR_INVALID_NETWORK


def test_get_confirmed_balance(binance_address):
    res = blockstream.get_confirmed_balance(binance_address)
    assert res.unwrap() > 0
